@@ -98,16 +98,17 @@
 #include <Qt3DExtras/qnormaldiffusespecularmapmaterial.h>
 #include <Qt3DExtras/qtorusgeometryview.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
