@@ -105,16 +105,17 @@
 #include <QtCharts/qhorizontalpercentbarseries.h>
 #include <QtCharts/qlineseries.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
@@ -215,15 +216,17 @@ enum : int {
     SBK_QTCHARTS_QLIST_QABSTRACTAXISPTR_IDX                  = 6, // QList<QAbstractAxis* >
     SBK_QTCHARTS_QLIST_QABSTRACTSERIESPTR_IDX                = 7, // QList<QAbstractSeries* >
     SBK_QTCHARTS_QLIST_QREAL_IDX                             = 8, // QList<qreal >
-    SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 9, // QList<QPointF >
-    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 10, // QList<QPieSlice* >
-    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 11, // QList<QCandlestickSet* >
-    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 12, // QList<QBoxSet* >
-    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 13, // QList<QBarSet* >
-    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 14, // QList<QVariant >
-    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 15, // QList<QString >
-    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 16, // QMap<QString,QVariant >
-    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 17
+    SBK_QTCHARTS_QLIST_INT_IDX                               = 9, // QList<int >
+    SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 10, // QList<QPointF >
+    SBK_QTCHARTS_QPAIR_QREAL_QREAL_IDX                       = 11, // QPair<qreal,qreal >
+    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 12, // QList<QPieSlice* >
+    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 13, // QList<QCandlestickSet* >
+    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 14, // QList<QBoxSet* >
+    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 15, // QList<QBarSet* >
+    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 16, // QList<QVariant >
+    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 17, // QList<QString >
+    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 18, // QMap<QString,QVariant >
+    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 19
 };
 // Macros for type check
 
