@@ -89,16 +89,17 @@
 #include <QtNetwork/qsslpresharedkeyauthenticator.h>
 #include <QtNetwork/qnetworkrequest.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
@@ -130,100 +131,102 @@ enum : int {
     SBK_QDTLS_HANDSHAKESTATE_IDX                             = 19,
     SBK_QDTLS_IDX                                            = 18,
     SBK_QDTLSCLIENTVERIFIER_IDX                              = 20,
-    SBK_QHOSTADDRESS_SPECIALADDRESS_IDX                      = 33,
-    SBK_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX                  = 32,
+    SBK_QHOSTADDRESS_SPECIALADDRESS_IDX                      = 34,
+    SBK_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX                  = 33,
     SBK_QFLAGS_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX           = 24,
-    SBK_QHOSTADDRESS_IDX                                     = 31,
-    SBK_QHOSTINFO_HOSTINFOERROR_IDX                          = 35,
-    SBK_QHOSTINFO_IDX                                        = 34,
-    SBK_QHSTSPOLICY_POLICYFLAG_IDX                           = 37,
+    SBK_QHOSTADDRESS_IDX                                     = 32,
+    SBK_QHOSTINFO_HOSTINFOERROR_IDX                          = 36,
+    SBK_QHOSTINFO_IDX                                        = 35,
+    SBK_QHSTSPOLICY_POLICYFLAG_IDX                           = 38,
     SBK_QFLAGS_QHSTSPOLICY_POLICYFLAG_IDX                    = 25,
-    SBK_QHSTSPOLICY_IDX                                      = 36,
-    SBK_QHTTP2CONFIGURATION_IDX                              = 38,
-    SBK_QHTTPMULTIPART_CONTENTTYPE_IDX                       = 40,
-    SBK_QHTTPMULTIPART_IDX                                   = 39,
-    SBK_QHTTPPART_IDX                                        = 41,
-    SBK_QIPV6ADDRESS_IDX                                     = 42,
-    SBK_QLOCALSERVER_SOCKETOPTION_IDX                        = 44,
+    SBK_QHSTSPOLICY_IDX                                      = 37,
+    SBK_QHTTP2CONFIGURATION_IDX                              = 39,
+    SBK_QHTTPMULTIPART_CONTENTTYPE_IDX                       = 41,
+    SBK_QHTTPMULTIPART_IDX                                   = 40,
+    SBK_QHTTPPART_IDX                                        = 42,
+    SBK_QIPV6ADDRESS_IDX                                     = 43,
+    SBK_QLOCALSERVER_SOCKETOPTION_IDX                        = 45,
     SBK_QFLAGS_QLOCALSERVER_SOCKETOPTION_IDX                 = 26,
-    SBK_QLOCALSERVER_IDX                                     = 43,
-    SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX                    = 46,
-    SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX                    = 47,
-    SBK_QLOCALSOCKET_IDX                                     = 45,
-    SBK_QNETWORKACCESSMANAGER_OPERATION_IDX                  = 49,
-    SBK_QNETWORKACCESSMANAGER_IDX                            = 48,
-    SBK_QNETWORKADDRESSENTRY_DNSELIGIBILITYSTATUS_IDX        = 51,
-    SBK_QNETWORKADDRESSENTRY_IDX                             = 50,
-    SBK_QNETWORKCACHEMETADATA_IDX                            = 52,
-    SBK_QNETWORKCOOKIE_RAWFORM_IDX                           = 54,
-    SBK_QNETWORKCOOKIE_SAMESITE_IDX                          = 55,
-    SBK_QNETWORKCOOKIE_IDX                                   = 53,
-    SBK_QNETWORKCOOKIEJAR_IDX                                = 56,
-    SBK_QNETWORKDATAGRAM_IDX                                 = 57,
-    SBK_QNETWORKDISKCACHE_IDX                                = 58,
-    SBK_QNETWORKINFORMATION_REACHABILITY_IDX                 = 61,
-    SBK_QNETWORKINFORMATION_FEATURE_IDX                      = 60,
-    SBK_QFLAGS_QNETWORKINFORMATION_FEATURE_IDX               = 27,
-    SBK_QNETWORKINFORMATION_IDX                              = 59,
-    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 63,
-    SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX           = 28,
-    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 64,
-    SBK_QNETWORKINTERFACE_IDX                                = 62,
-    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 67,
-    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 66,
-    SBK_QFLAGS_QNETWORKPROXY_CAPABILITY_IDX                  = 29,
-    SBK_QNETWORKPROXY_IDX                                    = 65,
-    SBK_QNETWORKPROXYFACTORY_IDX                             = 68,
-    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 70,
-    SBK_QNETWORKPROXYQUERY_IDX                               = 69,
-    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 72,
-    SBK_QNETWORKREPLY_IDX                                    = 71,
-    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 76,
-    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 74,
-    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 75,
-    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 77,
-    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 78,
-    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 79,
-    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 80,
-    SBK_QNETWORKREQUEST_IDX                                  = 73,
-    SBK_QOCSPRESPONSE_IDX                                    = 82,
-    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 84,
-    SBK_QSSL_KEYTYPE_IDX                                     = 92,
-    SBK_QSSL_ENCODINGFORMAT_IDX                              = 89,
-    SBK_QSSL_KEYALGORITHM_IDX                                = 91,
-    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 88,
-    SBK_QSSL_SSLPROTOCOL_IDX                                 = 94,
-    SBK_QSSL_SSLOPTION_IDX                                   = 93,
-    SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 30,
-    SBK_QSSL_ALERTLEVEL_IDX                                  = 86,
-    SBK_QSSL_ALERTTYPE_IDX                                   = 87,
-    SBK_QSSL_IMPLEMENTEDCLASS_IDX                            = 90,
-    SBK_QSSL_SUPPORTEDFEATURE_IDX                            = 95,
-    SBK_QtNetworkQSSL_IDX                                    = 85,
-    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 98,
-    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 97,
-    SBK_QSSLCERTIFICATE_IDX                                  = 96,
-    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 99,
-    SBK_QSSLCIPHER_IDX                                       = 100,
-    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 102,
-    SBK_QSSLCONFIGURATION_IDX                                = 101,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 104,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 103,
-    SBK_QSSLELLIPTICCURVE_IDX                                = 105,
-    SBK_QSSLERROR_SSLERROR_IDX                               = 107,
-    SBK_QSSLERROR_IDX                                        = 106,
-    SBK_QSSLKEY_IDX                                          = 108,
-    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 109,
-    SBK_QSSLSOCKET_SSLMODE_IDX                               = 112,
-    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 111,
-    SBK_QSSLSOCKET_IDX                                       = 110,
-    SBK_QTCPSERVER_IDX                                       = 113,
-    SBK_QTCPSOCKET_IDX                                       = 114,
-    SBK_QUDPSOCKET_IDX                                       = 115,
+    SBK_QLOCALSERVER_IDX                                     = 44,
+    SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX                    = 47,
+    SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX                    = 48,
+    SBK_QLOCALSOCKET_SOCKETOPTION_IDX                        = 49,
+    SBK_QFLAGS_QLOCALSOCKET_SOCKETOPTION_IDX                 = 27,
+    SBK_QLOCALSOCKET_IDX                                     = 46,
+    SBK_QNETWORKACCESSMANAGER_OPERATION_IDX                  = 51,
+    SBK_QNETWORKACCESSMANAGER_IDX                            = 50,
+    SBK_QNETWORKADDRESSENTRY_DNSELIGIBILITYSTATUS_IDX        = 53,
+    SBK_QNETWORKADDRESSENTRY_IDX                             = 52,
+    SBK_QNETWORKCACHEMETADATA_IDX                            = 54,
+    SBK_QNETWORKCOOKIE_RAWFORM_IDX                           = 56,
+    SBK_QNETWORKCOOKIE_SAMESITE_IDX                          = 57,
+    SBK_QNETWORKCOOKIE_IDX                                   = 55,
+    SBK_QNETWORKCOOKIEJAR_IDX                                = 58,
+    SBK_QNETWORKDATAGRAM_IDX                                 = 59,
+    SBK_QNETWORKDISKCACHE_IDX                                = 60,
+    SBK_QNETWORKINFORMATION_REACHABILITY_IDX                 = 63,
+    SBK_QNETWORKINFORMATION_FEATURE_IDX                      = 62,
+    SBK_QFLAGS_QNETWORKINFORMATION_FEATURE_IDX               = 28,
+    SBK_QNETWORKINFORMATION_IDX                              = 61,
+    SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX                  = 65,
+    SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX           = 29,
+    SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX                  = 66,
+    SBK_QNETWORKINTERFACE_IDX                                = 64,
+    SBK_QNETWORKPROXY_PROXYTYPE_IDX                          = 69,
+    SBK_QNETWORKPROXY_CAPABILITY_IDX                         = 68,
+    SBK_QFLAGS_QNETWORKPROXY_CAPABILITY_IDX                  = 30,
+    SBK_QNETWORKPROXY_IDX                                    = 67,
+    SBK_QNETWORKPROXYFACTORY_IDX                             = 70,
+    SBK_QNETWORKPROXYQUERY_QUERYTYPE_IDX                     = 72,
+    SBK_QNETWORKPROXYQUERY_IDX                               = 71,
+    SBK_QNETWORKREPLY_NETWORKERROR_IDX                       = 74,
+    SBK_QNETWORKREPLY_IDX                                    = 73,
+    SBK_QNETWORKREQUEST_KNOWNHEADERS_IDX                     = 78,
+    SBK_QNETWORKREQUEST_ATTRIBUTE_IDX                        = 76,
+    SBK_QNETWORKREQUEST_CACHELOADCONTROL_IDX                 = 77,
+    SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 79,
+    SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 80,
+    SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 81,
+    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 82,
+    SBK_QNETWORKREQUEST_IDX                                  = 75,
+    SBK_QOCSPRESPONSE_IDX                                    = 84,
+    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 86,
+    SBK_QSSL_KEYTYPE_IDX                                     = 94,
+    SBK_QSSL_ENCODINGFORMAT_IDX                              = 91,
+    SBK_QSSL_KEYALGORITHM_IDX                                = 93,
+    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 90,
+    SBK_QSSL_SSLPROTOCOL_IDX                                 = 96,
+    SBK_QSSL_SSLOPTION_IDX                                   = 95,
+    SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 31,
+    SBK_QSSL_ALERTLEVEL_IDX                                  = 88,
+    SBK_QSSL_ALERTTYPE_IDX                                   = 89,
+    SBK_QSSL_IMPLEMENTEDCLASS_IDX                            = 92,
+    SBK_QSSL_SUPPORTEDFEATURE_IDX                            = 97,
+    SBK_QtNetworkQSSL_IDX                                    = 87,
+    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 100,
+    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 99,
+    SBK_QSSLCERTIFICATE_IDX                                  = 98,
+    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 101,
+    SBK_QSSLCIPHER_IDX                                       = 102,
+    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 104,
+    SBK_QSSLCONFIGURATION_IDX                                = 103,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 106,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 105,
+    SBK_QSSLELLIPTICCURVE_IDX                                = 107,
+    SBK_QSSLERROR_SSLERROR_IDX                               = 109,
+    SBK_QSSLERROR_IDX                                        = 108,
+    SBK_QSSLKEY_IDX                                          = 110,
+    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 111,
+    SBK_QSSLSOCKET_SSLMODE_IDX                               = 114,
+    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 113,
+    SBK_QSSLSOCKET_IDX                                       = 112,
+    SBK_QTCPSERVER_IDX                                       = 115,
+    SBK_QTCPSOCKET_IDX                                       = 116,
+    SBK_QUDPSOCKET_IDX                                       = 117,
     SBK_QDTLSERROR_IDX                                       = 21,
-    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 81,
-    SBK_QOCSPREVOCATIONREASON_IDX                            = 83,
-    SBK_QtNetwork_IDX_COUNT                                  = 116
+    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 83,
+    SBK_QOCSPREVOCATIONREASON_IDX                            = 85,
+    SBK_QtNetwork_IDX_COUNT                                  = 118
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtNetworkTypes;
@@ -248,17 +251,17 @@ enum : int {
     SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 9, // QHash<QNetworkRequest::Attribute,QVariant >
     SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 10, // std::pair<QByteArray,QByteArray >
     SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 11, // QList<std::pair< QByteArray,QByteArray > >
-    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 12, // QPair<QHostAddress,int >
-    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 13, // QHash<QString,QVariant >
-    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 14, // QList<QObject* >
-    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 15, // QList<QNetworkCookie >
-    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 16, // QList<QHstsPolicy >
-    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 17, // QList<QSslError >
-    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 18, // QList<QDnsDomainNameRecord >
-    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 19, // QList<QDnsHostAddressRecord >
-    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 20, // QList<QDnsMailExchangeRecord >
-    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 21, // QList<QDnsServiceRecord >
-    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 22, // QList<QDnsTextRecord >
+    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 12, // QHash<QString,QVariant >
+    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 13, // QList<QObject* >
+    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 14, // QList<QNetworkCookie >
+    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 15, // QList<QHstsPolicy >
+    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 16, // QList<QSslError >
+    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 17, // QList<QDnsDomainNameRecord >
+    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 18, // QList<QDnsHostAddressRecord >
+    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 19, // QList<QDnsMailExchangeRecord >
+    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 20, // QList<QDnsServiceRecord >
+    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 21, // QList<QDnsTextRecord >
+    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 22, // QPair<QHostAddress,int >
     SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 23, // QList<QString >
     SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 24, // QList<QSsl::ImplementedClass >
     SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 25, // QList<QOcspResponse >
@@ -323,6 +326,8 @@ template<> inline PyTypeObject *SbkType< ::QFlags<QLocalServer::SocketOption> >(
 template<> inline PyTypeObject *SbkType< ::QLocalServer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QLOCALSERVER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QLocalSocket::LocalSocketError >() { return SbkPySide6_QtNetworkTypes[SBK_QLOCALSOCKET_LOCALSOCKETERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QLocalSocket::LocalSocketState >() { return SbkPySide6_QtNetworkTypes[SBK_QLOCALSOCKET_LOCALSOCKETSTATE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QLocalSocket::SocketOption >() { return SbkPySide6_QtNetworkTypes[SBK_QLOCALSOCKET_SOCKETOPTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QLocalSocket::SocketOption> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QLOCALSOCKET_SOCKETOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QLocalSocket >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QLOCALSOCKET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager::Operation >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_OPERATION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_IDX]); }
