@@ -92,16 +92,17 @@
 #include <QtOpenGL/qopenglfunctions_1_4.h>
 #include <QtOpenGL/qopenglfunctions_4_4_core.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
@@ -212,13 +213,14 @@ enum : int {
     SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 4, // QList<unsigned int >
     SBK_QTOPENGL_QLIST_QOBJECTPTR_IDX                        = 5, // QList<QObject* >
     SBK_QTOPENGL_QLIST_QBYTEARRAY_IDX                        = 6, // QList<QByteArray >
-    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 7, // QList<float >
-    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 8, // QList<QOpenGLShader* >
-    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 9, // QList<QOpenGLDebugMessage >
-    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 10, // QList<QVariant >
-    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 11, // QList<QString >
-    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 12, // QMap<QString,QVariant >
-    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 13
+    SBK_QTOPENGL_QLIST_UINT64_T_IDX                          = 7, // QList<uint64_t >
+    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 8, // QList<float >
+    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 9, // QList<QOpenGLShader* >
+    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 10, // QList<QOpenGLDebugMessage >
+    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 11, // QList<QVariant >
+    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 12, // QList<QString >
+    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 13, // QMap<QString,QVariant >
+    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 14
 };
 // Macros for type check
 
